==> central-2.19.7-linux-amd64.tar.zst: release-v2.19.7/packages/shared/src/utils/patientCertificates/surveyAnswers.js <==
import { PROGRAM_DATA_ELEMENT_TYPES, RESULT_COLORS } from '@tamanu/constants';

const shouldShow = component => {
  switch (component.dataElement.type) {
    case PROGRAM_DATA_ELEMENT_TYPES.INSTRUCTION:
      return false;
    case PROGRAM_DATA_ELEMENT_TYPES.SURVEY_LINK:
      return false;
    default:
      return true;
  }
};

export const convertBinaryToYesNo = value => {
  switch (value) {
    case 'true':
    case '1':
      return 'Yes';
    case 'false':
    case '0':
      return 'No';
    default:
      return value;
  }
};

export const getSurveyAnswerRows = ({ components, answers }) =>
  components
    .filter(shouldShow)
    .map(component => {
      const { dataElement, id, screenIndex } = component;
      const { type, name } = dataElement;
      const answerObject = answers.find(a => a.dataElementId === dataElement.id);
      const answer = answerObject?.body;
      return {
        id,
        type,
        answer,
        name,
        screenIndex,
      };
    })
    .filter(r => r.answer !== undefined);

export const separateColorText = resultText => {
  for (const [key, color] of Object.entries(RESULT_COLORS)) {
    // only match colors at the end that follow a result
    // "90% GREEN" -> "90%"
    // "blue ribbon" -> "blue ribbon"
    // "reduced risk" -> "reduced risk"
    const re = RegExp(` ${key}$`, 'i');
    if (resultText.match(re)) {
      const strippedResultText = resultText.replace(re, '').trim();
      return { color, strippedResultText };
    }
  }
  return {
    strippedResultText: resultText,
  };
};

export const getResultName = components => {
  const resultComponent = components.find(component => component.dataElement.type === 'Result');
  return resultComponent?.dataElement.defaultText;
};

==> central-2.30.4-linux-amd64.tar.zst: release-v2.30.4/packages/shared/src/utils/patientCertificates/surveyAnswers.js <==
import { PROGRAM_DATA_ELEMENT_TYPES, RESULT_COLORS } from '@tamanu/constants';

const shouldShow = component => {
  switch (component.dataElement.type) {
    case PROGRAM_DATA_ELEMENT_TYPES.INSTRUCTION:
      return false;
    case PROGRAM_DATA_ELEMENT_TYPES.SURVEY_LINK:
      return false;
    default:
      return true;
  }
};

export const getSurveyAnswerRows = ({ components, answers }) =>
  components
    .filter(shouldShow)
    .map(component => {
      const { dataElement, id, screenIndex } = component;
      const { type, name } = dataElement;
      const answerObject = answers.find(a => a.dataElementId === dataElement.id);
      const answer = answerObject?.body;
      const sourceType = answerObject?.sourceType;
      return {
        id,
        type,
        answer,
        name,
        screenIndex,
        sourceType,
      };
    })
    .filter(r => r.answer !== undefined);

export const separateColorText = resultText => {
  for (const [key, color] of Object.entries(RESULT_COLORS)) {
    // only match colors at the end that follow a result
    // "90% GREEN" -> "90%"
    // "blue ribbon" -> "blue ribbon"
    // "reduced risk" -> "reduced risk"
    const re = RegExp(` ${key}$`, 'i');
    if (resultText.match(re)) {
      const strippedResultText = resultText.replace(re, '').trim();
      return { color, strippedResultText };
    }
  }
  return {
    strippedResultText: resultText,
  };
};

export const getResultName = components => {
  const resultComponent = components.find(component => component.dataElement.type === 'Result');
  return resultComponent?.dataElement.defaultText;
};
